![alt text](https://travis-ci.org/xliiv/pis.svg?branch=travis)


# pis (Pis Installs Sources)

pis: Install python package as cloned repo from guessed VCS (git, hg, etc.)
repository.


## Example:

```
$ pis requests

TODO Rest of content

```

## Installation

`pip install pis`


## TODO:

* install package from tag, like `pis requests==2.7.0`
